# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
PCDM module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_pcdm.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _PCDM
else:
    import _PCDM

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _PCDM.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _PCDM.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _PCDM.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _PCDM.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _PCDM.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _PCDM.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _PCDM.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _PCDM.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _PCDM.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _PCDM.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _PCDM.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _PCDM.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _PCDM.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _PCDM.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _PCDM.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _PCDM.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _PCDM.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _PCDM:
_PCDM.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _PCDM.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Storage
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.CDM
import OCC.Core.Resource

from enum import IntEnum
from OCC.Core.Exception import *

PCDM_SS_OK = _PCDM.PCDM_SS_OK
PCDM_SS_DriverFailure = _PCDM.PCDM_SS_DriverFailure
PCDM_SS_WriteFailure = _PCDM.PCDM_SS_WriteFailure
PCDM_SS_Failure = _PCDM.PCDM_SS_Failure
PCDM_SS_Doc_IsNull = _PCDM.PCDM_SS_Doc_IsNull
PCDM_SS_No_Obj = _PCDM.PCDM_SS_No_Obj
PCDM_SS_Info_Section_Error = _PCDM.PCDM_SS_Info_Section_Error
PCDM_SS_UserBreak = _PCDM.PCDM_SS_UserBreak
PCDM_TOFD_File = _PCDM.PCDM_TOFD_File
PCDM_TOFD_CmpFile = _PCDM.PCDM_TOFD_CmpFile
PCDM_TOFD_XmlFile = _PCDM.PCDM_TOFD_XmlFile
PCDM_TOFD_Unknown = _PCDM.PCDM_TOFD_Unknown
PCDM_RS_OK = _PCDM.PCDM_RS_OK
PCDM_RS_NoDriver = _PCDM.PCDM_RS_NoDriver
PCDM_RS_UnknownFileDriver = _PCDM.PCDM_RS_UnknownFileDriver
PCDM_RS_OpenError = _PCDM.PCDM_RS_OpenError
PCDM_RS_NoVersion = _PCDM.PCDM_RS_NoVersion
PCDM_RS_NoSchema = _PCDM.PCDM_RS_NoSchema
PCDM_RS_NoDocument = _PCDM.PCDM_RS_NoDocument
PCDM_RS_ExtensionFailure = _PCDM.PCDM_RS_ExtensionFailure
PCDM_RS_WrongStreamMode = _PCDM.PCDM_RS_WrongStreamMode
PCDM_RS_FormatFailure = _PCDM.PCDM_RS_FormatFailure
PCDM_RS_TypeFailure = _PCDM.PCDM_RS_TypeFailure
PCDM_RS_TypeNotFoundInSchema = _PCDM.PCDM_RS_TypeNotFoundInSchema
PCDM_RS_UnrecognizedFileFormat = _PCDM.PCDM_RS_UnrecognizedFileFormat
PCDM_RS_MakeFailure = _PCDM.PCDM_RS_MakeFailure
PCDM_RS_PermissionDenied = _PCDM.PCDM_RS_PermissionDenied
PCDM_RS_DriverFailure = _PCDM.PCDM_RS_DriverFailure
PCDM_RS_AlreadyRetrievedAndModified = _PCDM.PCDM_RS_AlreadyRetrievedAndModified
PCDM_RS_AlreadyRetrieved = _PCDM.PCDM_RS_AlreadyRetrieved
PCDM_RS_UnknownDocument = _PCDM.PCDM_RS_UnknownDocument
PCDM_RS_WrongResource = _PCDM.PCDM_RS_WrongResource
PCDM_RS_ReaderException = _PCDM.PCDM_RS_ReaderException
PCDM_RS_NoModel = _PCDM.PCDM_RS_NoModel
PCDM_RS_UserBreak = _PCDM.PCDM_RS_UserBreak


class PCDM_StoreStatus(IntEnum):
	PCDM_SS_OK = 0
	PCDM_SS_DriverFailure = 1
	PCDM_SS_WriteFailure = 2
	PCDM_SS_Failure = 3
	PCDM_SS_Doc_IsNull = 4
	PCDM_SS_No_Obj = 5
	PCDM_SS_Info_Section_Error = 6
	PCDM_SS_UserBreak = 7
PCDM_SS_OK = PCDM_StoreStatus.PCDM_SS_OK
PCDM_SS_DriverFailure = PCDM_StoreStatus.PCDM_SS_DriverFailure
PCDM_SS_WriteFailure = PCDM_StoreStatus.PCDM_SS_WriteFailure
PCDM_SS_Failure = PCDM_StoreStatus.PCDM_SS_Failure
PCDM_SS_Doc_IsNull = PCDM_StoreStatus.PCDM_SS_Doc_IsNull
PCDM_SS_No_Obj = PCDM_StoreStatus.PCDM_SS_No_Obj
PCDM_SS_Info_Section_Error = PCDM_StoreStatus.PCDM_SS_Info_Section_Error
PCDM_SS_UserBreak = PCDM_StoreStatus.PCDM_SS_UserBreak

class PCDM_TypeOfFileDriver(IntEnum):
	PCDM_TOFD_File = 0
	PCDM_TOFD_CmpFile = 1
	PCDM_TOFD_XmlFile = 2
	PCDM_TOFD_Unknown = 3
PCDM_TOFD_File = PCDM_TypeOfFileDriver.PCDM_TOFD_File
PCDM_TOFD_CmpFile = PCDM_TypeOfFileDriver.PCDM_TOFD_CmpFile
PCDM_TOFD_XmlFile = PCDM_TypeOfFileDriver.PCDM_TOFD_XmlFile
PCDM_TOFD_Unknown = PCDM_TypeOfFileDriver.PCDM_TOFD_Unknown

class PCDM_ReaderStatus(IntEnum):
	PCDM_RS_OK = 0
	PCDM_RS_NoDriver = 1
	PCDM_RS_UnknownFileDriver = 2
	PCDM_RS_OpenError = 3
	PCDM_RS_NoVersion = 4
	PCDM_RS_NoSchema = 5
	PCDM_RS_NoDocument = 6
	PCDM_RS_ExtensionFailure = 7
	PCDM_RS_WrongStreamMode = 8
	PCDM_RS_FormatFailure = 9
	PCDM_RS_TypeFailure = 10
	PCDM_RS_TypeNotFoundInSchema = 11
	PCDM_RS_UnrecognizedFileFormat = 12
	PCDM_RS_MakeFailure = 13
	PCDM_RS_PermissionDenied = 14
	PCDM_RS_DriverFailure = 15
	PCDM_RS_AlreadyRetrievedAndModified = 16
	PCDM_RS_AlreadyRetrieved = 17
	PCDM_RS_UnknownDocument = 18
	PCDM_RS_WrongResource = 19
	PCDM_RS_ReaderException = 20
	PCDM_RS_NoModel = 21
	PCDM_RS_UserBreak = 22
PCDM_RS_OK = PCDM_ReaderStatus.PCDM_RS_OK
PCDM_RS_NoDriver = PCDM_ReaderStatus.PCDM_RS_NoDriver
PCDM_RS_UnknownFileDriver = PCDM_ReaderStatus.PCDM_RS_UnknownFileDriver
PCDM_RS_OpenError = PCDM_ReaderStatus.PCDM_RS_OpenError
PCDM_RS_NoVersion = PCDM_ReaderStatus.PCDM_RS_NoVersion
PCDM_RS_NoSchema = PCDM_ReaderStatus.PCDM_RS_NoSchema
PCDM_RS_NoDocument = PCDM_ReaderStatus.PCDM_RS_NoDocument
PCDM_RS_ExtensionFailure = PCDM_ReaderStatus.PCDM_RS_ExtensionFailure
PCDM_RS_WrongStreamMode = PCDM_ReaderStatus.PCDM_RS_WrongStreamMode
PCDM_RS_FormatFailure = PCDM_ReaderStatus.PCDM_RS_FormatFailure
PCDM_RS_TypeFailure = PCDM_ReaderStatus.PCDM_RS_TypeFailure
PCDM_RS_TypeNotFoundInSchema = PCDM_ReaderStatus.PCDM_RS_TypeNotFoundInSchema
PCDM_RS_UnrecognizedFileFormat = PCDM_ReaderStatus.PCDM_RS_UnrecognizedFileFormat
PCDM_RS_MakeFailure = PCDM_ReaderStatus.PCDM_RS_MakeFailure
PCDM_RS_PermissionDenied = PCDM_ReaderStatus.PCDM_RS_PermissionDenied
PCDM_RS_DriverFailure = PCDM_ReaderStatus.PCDM_RS_DriverFailure
PCDM_RS_AlreadyRetrievedAndModified = PCDM_ReaderStatus.PCDM_RS_AlreadyRetrievedAndModified
PCDM_RS_AlreadyRetrieved = PCDM_ReaderStatus.PCDM_RS_AlreadyRetrieved
PCDM_RS_UnknownDocument = PCDM_ReaderStatus.PCDM_RS_UnknownDocument
PCDM_RS_WrongResource = PCDM_ReaderStatus.PCDM_RS_WrongResource
PCDM_RS_ReaderException = PCDM_ReaderStatus.PCDM_RS_ReaderException
PCDM_RS_NoModel = PCDM_ReaderStatus.PCDM_RS_NoModel
PCDM_RS_UserBreak = PCDM_ReaderStatus.PCDM_RS_UserBreak


def Handle_PCDM_ReadWriter_Create() -> "opencascade::handle< PCDM_ReadWriter >":
    return _PCDM.Handle_PCDM_ReadWriter_Create()

def Handle_PCDM_ReadWriter_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_ReadWriter >":
    return _PCDM.Handle_PCDM_ReadWriter_DownCast(t)

def Handle_PCDM_ReadWriter_IsNull(t: "opencascade::handle< PCDM_ReadWriter > const &") -> "bool":
    return _PCDM.Handle_PCDM_ReadWriter_IsNull(t)

def Handle_PCDM_Reader_Create() -> "opencascade::handle< PCDM_Reader >":
    return _PCDM.Handle_PCDM_Reader_Create()

def Handle_PCDM_Reader_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_Reader >":
    return _PCDM.Handle_PCDM_Reader_DownCast(t)

def Handle_PCDM_Reader_IsNull(t: "opencascade::handle< PCDM_Reader > const &") -> "bool":
    return _PCDM.Handle_PCDM_Reader_IsNull(t)

def Handle_PCDM_ReferenceIterator_Create() -> "opencascade::handle< PCDM_ReferenceIterator >":
    return _PCDM.Handle_PCDM_ReferenceIterator_Create()

def Handle_PCDM_ReferenceIterator_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_ReferenceIterator >":
    return _PCDM.Handle_PCDM_ReferenceIterator_DownCast(t)

def Handle_PCDM_ReferenceIterator_IsNull(t: "opencascade::handle< PCDM_ReferenceIterator > const &") -> "bool":
    return _PCDM.Handle_PCDM_ReferenceIterator_IsNull(t)

def Handle_PCDM_Writer_Create() -> "opencascade::handle< PCDM_Writer >":
    return _PCDM.Handle_PCDM_Writer_Create()

def Handle_PCDM_Writer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_Writer >":
    return _PCDM.Handle_PCDM_Writer_DownCast(t)

def Handle_PCDM_Writer_IsNull(t: "opencascade::handle< PCDM_Writer > const &") -> "bool":
    return _PCDM.Handle_PCDM_Writer_IsNull(t)

def Handle_PCDM_ReadWriter_1_Create() -> "opencascade::handle< PCDM_ReadWriter_1 >":
    return _PCDM.Handle_PCDM_ReadWriter_1_Create()

def Handle_PCDM_ReadWriter_1_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_ReadWriter_1 >":
    return _PCDM.Handle_PCDM_ReadWriter_1_DownCast(t)

def Handle_PCDM_ReadWriter_1_IsNull(t: "opencascade::handle< PCDM_ReadWriter_1 > const &") -> "bool":
    return _PCDM.Handle_PCDM_ReadWriter_1_IsNull(t)

def Handle_PCDM_RetrievalDriver_Create() -> "opencascade::handle< PCDM_RetrievalDriver >":
    return _PCDM.Handle_PCDM_RetrievalDriver_Create()

def Handle_PCDM_RetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_RetrievalDriver >":
    return _PCDM.Handle_PCDM_RetrievalDriver_DownCast(t)

def Handle_PCDM_RetrievalDriver_IsNull(t: "opencascade::handle< PCDM_RetrievalDriver > const &") -> "bool":
    return _PCDM.Handle_PCDM_RetrievalDriver_IsNull(t)

def Handle_PCDM_StorageDriver_Create() -> "opencascade::handle< PCDM_StorageDriver >":
    return _PCDM.Handle_PCDM_StorageDriver_Create()

def Handle_PCDM_StorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< PCDM_StorageDriver >":
    return _PCDM.Handle_PCDM_StorageDriver_DownCast(t)

def Handle_PCDM_StorageDriver_IsNull(t: "opencascade::handle< PCDM_StorageDriver > const &") -> "bool":
    return _PCDM.Handle_PCDM_StorageDriver_IsNull(t)
class PCDM_BaseDriverPointer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _PCDM.PCDM_BaseDriverPointer_swiginit(self, _PCDM.new_PCDM_BaseDriverPointer())
    __swig_destroy__ = _PCDM.delete_PCDM_BaseDriverPointer

# Register PCDM_BaseDriverPointer in _PCDM:
_PCDM.PCDM_BaseDriverPointer_swigregister(PCDM_BaseDriverPointer)

class PCDM_SequenceOfDocument(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< PCDM_Document > >::iterator":
        return _PCDM.PCDM_SequenceOfDocument_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< PCDM_Document > >::iterator":
        return _PCDM.PCDM_SequenceOfDocument_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< PCDM_Document > >::const_iterator":
        return _PCDM.PCDM_SequenceOfDocument_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< PCDM_Document > >::const_iterator":
        return _PCDM.PCDM_SequenceOfDocument_cend(self)

    def __init__(self, *args):
        _PCDM.PCDM_SequenceOfDocument_swiginit(self, _PCDM.new_PCDM_SequenceOfDocument(*args))

    def Size(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfDocument_Size(self)

    def Length(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfDocument_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfDocument_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfDocument_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _PCDM.PCDM_SequenceOfDocument_IsEmpty(self)

    def Reverse(self) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _PCDM.PCDM_SequenceOfDocument_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Clear(self, theAllocator)

    def Assign(self, theOther: "PCDM_SequenceOfDocument") -> "NCollection_Sequence< opencascade::handle< PCDM_Document > > &":
        return _PCDM.PCDM_SequenceOfDocument_Assign(self, theOther)

    def Set(self, theOther: "PCDM_SequenceOfDocument") -> "NCollection_Sequence< opencascade::handle< PCDM_Document > > &":
        return _PCDM.PCDM_SequenceOfDocument_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfDocument_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "PCDM_SequenceOfDocument") -> "void":
        return _PCDM.PCDM_SequenceOfDocument_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< PCDM_Document > const &":
        return _PCDM.PCDM_SequenceOfDocument_First(self)

    def ChangeFirst(self) -> "opencascade::handle< PCDM_Document > &":
        return _PCDM.PCDM_SequenceOfDocument_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< PCDM_Document > const &":
        return _PCDM.PCDM_SequenceOfDocument_Last(self)

    def ChangeLast(self) -> "opencascade::handle< PCDM_Document > &":
        return _PCDM.PCDM_SequenceOfDocument_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< PCDM_Document > const &":
        return _PCDM.PCDM_SequenceOfDocument_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< PCDM_Document > &":
        return _PCDM.PCDM_SequenceOfDocument_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< PCDM_Document > &":
        return _PCDM.PCDM_SequenceOfDocument___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< PCDM_Document > const &") -> "void":
        return _PCDM.PCDM_SequenceOfDocument_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _PCDM.delete_PCDM_SequenceOfDocument

    def __len__(self):
        return self.Size()


# Register PCDM_SequenceOfDocument in _PCDM:
_PCDM.PCDM_SequenceOfDocument_swigregister(PCDM_SequenceOfDocument)

def PCDM_SequenceOfDocument_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _PCDM.PCDM_SequenceOfDocument_delNode(theNode, theAl)

class PCDM_SequenceOfReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< PCDM_Reference >::iterator":
        return _PCDM.PCDM_SequenceOfReference_begin(self)

    def end(self) -> "NCollection_Sequence< PCDM_Reference >::iterator":
        return _PCDM.PCDM_SequenceOfReference_end(self)

    def cbegin(self) -> "NCollection_Sequence< PCDM_Reference >::const_iterator":
        return _PCDM.PCDM_SequenceOfReference_cbegin(self)

    def cend(self) -> "NCollection_Sequence< PCDM_Reference >::const_iterator":
        return _PCDM.PCDM_SequenceOfReference_cend(self)

    def __init__(self, *args):
        _PCDM.PCDM_SequenceOfReference_swiginit(self, _PCDM.new_PCDM_SequenceOfReference(*args))

    def Size(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfReference_Size(self)

    def Length(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfReference_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfReference_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _PCDM.PCDM_SequenceOfReference_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _PCDM.PCDM_SequenceOfReference_IsEmpty(self)

    def Reverse(self) -> "void":
        return _PCDM.PCDM_SequenceOfReference_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _PCDM.PCDM_SequenceOfReference_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _PCDM.PCDM_SequenceOfReference_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _PCDM.PCDM_SequenceOfReference_Clear(self, theAllocator)

    def Assign(self, theOther: "PCDM_SequenceOfReference") -> "NCollection_Sequence< PCDM_Reference > &":
        return _PCDM.PCDM_SequenceOfReference_Assign(self, theOther)

    def Set(self, theOther: "PCDM_SequenceOfReference") -> "NCollection_Sequence< PCDM_Reference > &":
        return _PCDM.PCDM_SequenceOfReference_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfReference_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfReference_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfReference_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfReference_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _PCDM.PCDM_SequenceOfReference_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "PCDM_SequenceOfReference") -> "void":
        return _PCDM.PCDM_SequenceOfReference_Split(self, theIndex, theSeq)

    def First(self) -> "PCDM_Reference const &":
        return _PCDM.PCDM_SequenceOfReference_First(self)

    def ChangeFirst(self) -> "PCDM_Reference &":
        return _PCDM.PCDM_SequenceOfReference_ChangeFirst(self)

    def Last(self) -> "PCDM_Reference const &":
        return _PCDM.PCDM_SequenceOfReference_Last(self)

    def ChangeLast(self) -> "PCDM_Reference &":
        return _PCDM.PCDM_SequenceOfReference_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "PCDM_Reference const &":
        return _PCDM.PCDM_SequenceOfReference_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "PCDM_Reference &":
        return _PCDM.PCDM_SequenceOfReference_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "PCDM_Reference &":
        return _PCDM.PCDM_SequenceOfReference___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "PCDM_Reference") -> "void":
        return _PCDM.PCDM_SequenceOfReference_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _PCDM.delete_PCDM_SequenceOfReference

    def __len__(self):
        return self.Size()


# Register PCDM_SequenceOfReference in _PCDM:
_PCDM.PCDM_SequenceOfReference_swigregister(PCDM_SequenceOfReference)

def PCDM_SequenceOfReference_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _PCDM.PCDM_SequenceOfReference_delNode(theNode, theAl)

class pcdm(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def FileDriverType(*args) -> "PCDM_TypeOfFileDriver":
        r"""
        No available documentation.

        Parameters
        ----------
        aFileName: TCollection_AsciiString
        aBaseDriver: Storage_BaseDriver

        Returns
        -------
        PCDM_TypeOfFileDriver

        """
        return _PCDM.pcdm_FileDriverType(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _PCDM.pcdm_swiginit(self, _PCDM.new_pcdm())
    __swig_destroy__ = _PCDM.delete_pcdm

# Register pcdm in _PCDM:
_PCDM.pcdm_swigregister(pcdm)

def pcdm_FileDriverType(*args) -> "PCDM_TypeOfFileDriver":
    r"""
    No available documentation.

    Parameters
    ----------
    aFileName: TCollection_AsciiString
    aBaseDriver: Storage_BaseDriver

    Returns
    -------
    PCDM_TypeOfFileDriver

    """
    return _PCDM.pcdm_FileDriverType(*args)

class PCDM_ReadWriter(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def FileFormat(*args) -> "TCollection_ExtendedString":
        r"""
        Tries to get a format in the file. returns an empty string if the file could not be read or does not have a fileformat information.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString

        Returns
        -------
        TCollection_ExtendedString

        """
        return _PCDM.PCDM_ReadWriter_FileFormat(*args)

    @staticmethod
    def Open(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDriver: Storage_BaseDriver
        aFileName: TCollection_ExtendedString
        anOpenMode: Storage_OpenMode

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_Open(*args)

    def ReadDocumentVersion(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString
        theMsgDriver: Message_Messenger

        Returns
        -------
        int

        """
        return _PCDM.PCDM_ReadWriter_ReadDocumentVersion(self, *args)

    def ReadExtensions(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString
        theExtensions: TColStd_SequenceOfExtendedString
        theMsgDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_ReadExtensions(self, *args)

    def ReadReferenceCounter(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        theFileName: TCollection_ExtendedString
        theMsgDriver: Message_Messenger

        Returns
        -------
        int

        """
        return _PCDM.PCDM_ReadWriter_ReadReferenceCounter(self, *args)

    def ReadReferences(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString
        theReferences: PCDM_SequenceOfReference
        theMsgDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_ReadReferences(self, *args)

    @staticmethod
    def Reader(*args) -> "opencascade::handle< PCDM_ReadWriter >":
        r"""
        Returns the convenient reader for a file.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<PCDM_ReadWriter>

        """
        return _PCDM.PCDM_ReadWriter_Reader(*args)

    def Version(self, *args) -> "TCollection_AsciiString":
        r"""
        Returns pcdm_readwriter_1.

        Returns
        -------
        TCollection_AsciiString

        """
        return _PCDM.PCDM_ReadWriter_Version(self, *args)

    def WriteExtensions(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aData: Storage_Data
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_WriteExtensions(self, *args)

    @staticmethod
    def WriteFileFormat(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aData: Storage_Data
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_WriteFileFormat(*args)

    def WriteReferenceCounter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aData: Storage_Data
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_WriteReferenceCounter(self, *args)

    def WriteReferences(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aData: Storage_Data
        aDocument: CDM_Document
        theReferencerFileName: TCollection_ExtendedString

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_WriteReferences(self, *args)

    def WriteVersion(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aData: Storage_Data
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReadWriter_WriteVersion(self, *args)

    @staticmethod
    def Writer(*args) -> "opencascade::handle< PCDM_ReadWriter >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<PCDM_ReadWriter>

        """
        return _PCDM.PCDM_ReadWriter_Writer(*args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_ReadWriter_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_ReadWriter

# Register PCDM_ReadWriter in _PCDM:
_PCDM.PCDM_ReadWriter_swigregister(PCDM_ReadWriter)

def PCDM_ReadWriter_FileFormat(*args) -> "TCollection_ExtendedString":
    r"""
    Tries to get a format in the file. returns an empty string if the file could not be read or does not have a fileformat information.

    Parameters
    ----------
    aFileName: TCollection_ExtendedString

    Returns
    -------
    TCollection_ExtendedString

    """
    return _PCDM.PCDM_ReadWriter_FileFormat(*args)

def PCDM_ReadWriter_Open(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aDriver: Storage_BaseDriver
    aFileName: TCollection_ExtendedString
    anOpenMode: Storage_OpenMode

    Returns
    -------
    None

    """
    return _PCDM.PCDM_ReadWriter_Open(*args)

def PCDM_ReadWriter_Reader(*args) -> "opencascade::handle< PCDM_ReadWriter >":
    r"""
    Returns the convenient reader for a file.

    Parameters
    ----------
    aFileName: TCollection_ExtendedString

    Returns
    -------
    opencascade::handle<PCDM_ReadWriter>

    """
    return _PCDM.PCDM_ReadWriter_Reader(*args)

def PCDM_ReadWriter_WriteFileFormat(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aData: Storage_Data
    aDocument: CDM_Document

    Returns
    -------
    None

    """
    return _PCDM.PCDM_ReadWriter_WriteFileFormat(*args)

def PCDM_ReadWriter_Writer(*args) -> "opencascade::handle< PCDM_ReadWriter >":
    r"""
    No available documentation.

    Returns
    -------
    opencascade::handle<PCDM_ReadWriter>

    """
    return _PCDM.PCDM_ReadWriter_Writer(*args)

class PCDM_Reader(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def CreateDocument(self, *args) -> "opencascade::handle< CDM_Document >":
        r"""
        This method is called by the framework before the read method.

        Returns
        -------
        opencascade::handle<CDM_Document>

        """
        return _PCDM.PCDM_Reader_CreateDocument(self, *args)

    def GetStatus(self, *args) -> "PCDM_ReaderStatus":
        r"""
        No available documentation.

        Returns
        -------
        PCDM_ReaderStatus

        """
        return _PCDM.PCDM_Reader_GetStatus(self, *args)

    def Read(self, *args) -> "void":
        r"""
        Retrieves the content of the file into a new document.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString
        aNewDocument: CDM_Document
        anApplication: CDM_Application
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _PCDM.PCDM_Reader_Read(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_Reader_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_Reader

# Register PCDM_Reader in _PCDM:
_PCDM.PCDM_Reader_swigregister(PCDM_Reader)

class PCDM_Reference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aReferenceIdentifier: int
        aFileName: TCollection_ExtendedString
        aDocumentVersion: int

        Returns
        -------
        None

        """
        _PCDM.PCDM_Reference_swiginit(self, _PCDM.new_PCDM_Reference(*args))

    def DocumentVersion(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _PCDM.PCDM_Reference_DocumentVersion(self, *args)

    def FileName(self, *args) -> "TCollection_ExtendedString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_ExtendedString

        """
        return _PCDM.PCDM_Reference_FileName(self, *args)

    def ReferenceIdentifier(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _PCDM.PCDM_Reference_ReferenceIdentifier(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_Reference

# Register PCDM_Reference in _PCDM:
_PCDM.PCDM_Reference_swigregister(PCDM_Reference)

class PCDM_ReferenceIterator(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Warning! the constructor does not initialization.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _PCDM.PCDM_ReferenceIterator_swiginit(self, _PCDM.new_PCDM_ReferenceIterator(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMetaData: CDM_MetaData

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReferenceIterator_Init(self, *args)

    def LoadReferences(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDocument: CDM_Document
        aMetaData: CDM_MetaData
        anApplication: CDM_Application
        UseStorageConfiguration: bool

        Returns
        -------
        None

        """
        return _PCDM.PCDM_ReferenceIterator_LoadReferences(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_ReferenceIterator_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_ReferenceIterator

# Register PCDM_ReferenceIterator in _PCDM:
_PCDM.PCDM_ReferenceIterator_swigregister(PCDM_ReferenceIterator)

class PCDM_Writer(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Write(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDocument: CDM_Document
        aFileName: TCollection_ExtendedString
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _PCDM.PCDM_Writer_Write(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_Writer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_Writer

# Register PCDM_Writer in _PCDM:
_PCDM.PCDM_Writer_swigregister(PCDM_Writer)

class PCDM_ReadWriter_1(PCDM_ReadWriter):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _PCDM.PCDM_ReadWriter_1_swiginit(self, _PCDM.new_PCDM_ReadWriter_1(*args))


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_ReadWriter_1_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_ReadWriter_1

# Register PCDM_ReadWriter_1 in _PCDM:
_PCDM.PCDM_ReadWriter_1_swigregister(PCDM_ReadWriter_1)

class PCDM_RetrievalDriver(PCDM_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def DocumentVersion(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        theFileName: TCollection_ExtendedString
        theMsgDriver: Message_Messenger

        Returns
        -------
        int

        """
        return _PCDM.PCDM_RetrievalDriver_DocumentVersion(*args)

    def GetFormat(self, *args) -> "TCollection_ExtendedString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_ExtendedString

        """
        return _PCDM.PCDM_RetrievalDriver_GetFormat(self, *args)

    @staticmethod
    def ReferenceCounter(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        theFileName: TCollection_ExtendedString
        theMsgDriver: Message_Messenger

        Returns
        -------
        int

        """
        return _PCDM.PCDM_RetrievalDriver_ReferenceCounter(*args)

    def SetFormat(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aformat: TCollection_ExtendedString

        Returns
        -------
        None

        """
        return _PCDM.PCDM_RetrievalDriver_SetFormat(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_RetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _PCDM.delete_PCDM_RetrievalDriver

# Register PCDM_RetrievalDriver in _PCDM:
_PCDM.PCDM_RetrievalDriver_swigregister(PCDM_RetrievalDriver)

def PCDM_RetrievalDriver_DocumentVersion(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    theFileName: TCollection_ExtendedString
    theMsgDriver: Message_Messenger

    Returns
    -------
    int

    """
    return _PCDM.PCDM_RetrievalDriver_DocumentVersion(*args)

def PCDM_RetrievalDriver_ReferenceCounter(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    theFileName: TCollection_ExtendedString
    theMsgDriver: Message_Messenger

    Returns
    -------
    int

    """
    return _PCDM.PCDM_RetrievalDriver_ReferenceCounter(*args)

class PCDM_StorageDriver(PCDM_Writer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetFormat(self, *args) -> "TCollection_ExtendedString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_ExtendedString

        """
        return _PCDM.PCDM_StorageDriver_GetFormat(self, *args)

    def GetStoreStatus(self, *args) -> "PCDM_StoreStatus":
        r"""
        No available documentation.

        Returns
        -------
        PCDM_StoreStatus

        """
        return _PCDM.PCDM_StorageDriver_GetStoreStatus(self, *args)

    def IsError(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _PCDM.PCDM_StorageDriver_IsError(self, *args)

    def Make(self, *args) -> "void":
        r"""
        Raises notimplemented.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        opencascade::handle<PCDM_Document>
        By default, puts in the sequence the document returns by the previous make method.

        Parameters
        ----------
        aDocument: CDM_Document
        Documents: PCDM_SequenceOfDocument

        Returns
        -------
        None

        """
        return _PCDM.PCDM_StorageDriver_Make(self, *args)

    def SetFormat(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aformat: TCollection_ExtendedString

        Returns
        -------
        None

        """
        return _PCDM.PCDM_StorageDriver_SetFormat(self, *args)

    def SetIsError(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theIsError: bool

        Returns
        -------
        None

        """
        return _PCDM.PCDM_StorageDriver_SetIsError(self, *args)

    def SetStoreStatus(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theStoreStatus: PCDM_StoreStatus

        Returns
        -------
        None

        """
        return _PCDM.PCDM_StorageDriver_SetStoreStatus(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_PCDM_StorageDriver_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        _PCDM.PCDM_StorageDriver_swiginit(self, _PCDM.new_PCDM_StorageDriver())
    __swig_destroy__ = _PCDM.delete_PCDM_StorageDriver

# Register PCDM_StorageDriver in _PCDM:
_PCDM.PCDM_StorageDriver_swigregister(PCDM_StorageDriver)


@classnotwrapped
class PCDM_DOMHeaderParser:
	pass

@classnotwrapped
class PCDM_Document:
	pass









# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StdFail module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stdfail.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StdFail
else:
    import _StdFail

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StdFail.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StdFail.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StdFail.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StdFail.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StdFail.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StdFail.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StdFail.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StdFail.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StdFail.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StdFail.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StdFail.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StdFail.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StdFail.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StdFail.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StdFail.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StdFail.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StdFail.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StdFail:
_StdFail.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StdFail.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection

from enum import IntEnum
from OCC.Core.Exception import *










# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
HLRAppli module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_hlrappli.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _HLRAppli
else:
    import _HLRAppli

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _HLRAppli.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _HLRAppli.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _HLRAppli.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _HLRAppli.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _HLRAppli.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _HLRAppli.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _HLRAppli.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _HLRAppli.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _HLRAppli.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _HLRAppli.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _HLRAppli.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _HLRAppli.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _HLRAppli.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _HLRAppli.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _HLRAppli.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _HLRAppli.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _HLRAppli.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _HLRAppli:
_HLRAppli.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _HLRAppli.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.HLRBRep
import OCC.Core.HLRAlgo
import OCC.Core.TColgp
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.IntRes2d
import OCC.Core.TopTools
import OCC.Core.BRepTopAdaptor
import OCC.Core.IntCurveSurface
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.HLRTopoBRep
import OCC.Core.Contap
import OCC.Core.IntCurve
import OCC.Core.Extrema

from enum import IntEnum
from OCC.Core.Exception import *



class HLRAppli_ReflectLines(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Parameters
        ----------
        aShape: TopoDS_Shape

        Returns
        -------
        None

        """
        _HLRAppli.HLRAppli_ReflectLines_swiginit(self, _HLRAppli.new_HLRAppli_ReflectLines(*args))

    def GetCompoundOf3dEdges(self, *args) -> "TopoDS_Shape":
        r"""
        Returns resulting compound of lines of specified type and visibility represented by edges in 3d or 2d.

        Parameters
        ----------
        type: HLRBRep_TypeOfResultingEdge
        visible: bool
        In3d: bool

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRAppli.HLRAppli_ReflectLines_GetCompoundOf3dEdges(self, *args)

    def GetResult(self, *args) -> "TopoDS_Shape":
        r"""
        Returns resulting compound of reflect lines represented by edges in 3d.

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRAppli.HLRAppli_ReflectLines_GetResult(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _HLRAppli.HLRAppli_ReflectLines_Perform(self, *args)

    def SetAxes(self, *args) -> "void":
        r"""
        Sets the normal to the plane of visualisation, the coordinates of the view point and the coordinates of the vertical direction vector.

        Parameters
        ----------
        Nx: float
        Ny: float
        Nz: float
        XAt: float
        YAt: float
        ZAt: float
        XUp: float
        YUp: float
        ZUp: float

        Returns
        -------
        None

        """
        return _HLRAppli.HLRAppli_ReflectLines_SetAxes(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _HLRAppli.delete_HLRAppli_ReflectLines

# Register HLRAppli_ReflectLines in _HLRAppli:
_HLRAppli.HLRAppli_ReflectLines_swigregister(HLRAppli_ReflectLines)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinMDataStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_binmdatastd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinMDataStd
else:
    import _BinMDataStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinMDataStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinMDataStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinMDataStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinMDataStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinMDataStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinMDataStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinMDataStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinMDataStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinMDataStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinMDataStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinMDataStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinMDataStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinMDataStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinMDataStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinMDataStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinMDataStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinMDataStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinMDataStd:
_BinMDataStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinMDataStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BinMDF
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TDF
import OCC.Core.BinObjMgt
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BinMDataStd_AsciiStringDriver_Create() -> "opencascade::handle< BinMDataStd_AsciiStringDriver >":
    return _BinMDataStd.Handle_BinMDataStd_AsciiStringDriver_Create()

def Handle_BinMDataStd_AsciiStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_AsciiStringDriver >":
    return _BinMDataStd.Handle_BinMDataStd_AsciiStringDriver_DownCast(t)

def Handle_BinMDataStd_AsciiStringDriver_IsNull(t: "opencascade::handle< BinMDataStd_AsciiStringDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_AsciiStringDriver_IsNull(t)

def Handle_BinMDataStd_BooleanArrayDriver_Create() -> "opencascade::handle< BinMDataStd_BooleanArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_BooleanArrayDriver_Create()

def Handle_BinMDataStd_BooleanArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_BooleanArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_BooleanArrayDriver_DownCast(t)

def Handle_BinMDataStd_BooleanArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_BooleanArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_BooleanArrayDriver_IsNull(t)

def Handle_BinMDataStd_BooleanListDriver_Create() -> "opencascade::handle< BinMDataStd_BooleanListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_BooleanListDriver_Create()

def Handle_BinMDataStd_BooleanListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_BooleanListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_BooleanListDriver_DownCast(t)

def Handle_BinMDataStd_BooleanListDriver_IsNull(t: "opencascade::handle< BinMDataStd_BooleanListDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_BooleanListDriver_IsNull(t)

def Handle_BinMDataStd_ByteArrayDriver_Create() -> "opencascade::handle< BinMDataStd_ByteArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ByteArrayDriver_Create()

def Handle_BinMDataStd_ByteArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ByteArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ByteArrayDriver_DownCast(t)

def Handle_BinMDataStd_ByteArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_ByteArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ByteArrayDriver_IsNull(t)

def Handle_BinMDataStd_ExpressionDriver_Create() -> "opencascade::handle< BinMDataStd_ExpressionDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExpressionDriver_Create()

def Handle_BinMDataStd_ExpressionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ExpressionDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExpressionDriver_DownCast(t)

def Handle_BinMDataStd_ExpressionDriver_IsNull(t: "opencascade::handle< BinMDataStd_ExpressionDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ExpressionDriver_IsNull(t)

def Handle_BinMDataStd_ExtStringArrayDriver_Create() -> "opencascade::handle< BinMDataStd_ExtStringArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringArrayDriver_Create()

def Handle_BinMDataStd_ExtStringArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ExtStringArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringArrayDriver_DownCast(t)

def Handle_BinMDataStd_ExtStringArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_ExtStringArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringArrayDriver_IsNull(t)

def Handle_BinMDataStd_ExtStringListDriver_Create() -> "opencascade::handle< BinMDataStd_ExtStringListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringListDriver_Create()

def Handle_BinMDataStd_ExtStringListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ExtStringListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringListDriver_DownCast(t)

def Handle_BinMDataStd_ExtStringListDriver_IsNull(t: "opencascade::handle< BinMDataStd_ExtStringListDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ExtStringListDriver_IsNull(t)

def Handle_BinMDataStd_GenericEmptyDriver_Create() -> "opencascade::handle< BinMDataStd_GenericEmptyDriver >":
    return _BinMDataStd.Handle_BinMDataStd_GenericEmptyDriver_Create()

def Handle_BinMDataStd_GenericEmptyDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_GenericEmptyDriver >":
    return _BinMDataStd.Handle_BinMDataStd_GenericEmptyDriver_DownCast(t)

def Handle_BinMDataStd_GenericEmptyDriver_IsNull(t: "opencascade::handle< BinMDataStd_GenericEmptyDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_GenericEmptyDriver_IsNull(t)

def Handle_BinMDataStd_GenericExtStringDriver_Create() -> "opencascade::handle< BinMDataStd_GenericExtStringDriver >":
    return _BinMDataStd.Handle_BinMDataStd_GenericExtStringDriver_Create()

def Handle_BinMDataStd_GenericExtStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_GenericExtStringDriver >":
    return _BinMDataStd.Handle_BinMDataStd_GenericExtStringDriver_DownCast(t)

def Handle_BinMDataStd_GenericExtStringDriver_IsNull(t: "opencascade::handle< BinMDataStd_GenericExtStringDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_GenericExtStringDriver_IsNull(t)

def Handle_BinMDataStd_IntPackedMapDriver_Create() -> "opencascade::handle< BinMDataStd_IntPackedMapDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntPackedMapDriver_Create()

def Handle_BinMDataStd_IntPackedMapDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_IntPackedMapDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntPackedMapDriver_DownCast(t)

def Handle_BinMDataStd_IntPackedMapDriver_IsNull(t: "opencascade::handle< BinMDataStd_IntPackedMapDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_IntPackedMapDriver_IsNull(t)

def Handle_BinMDataStd_IntegerArrayDriver_Create() -> "opencascade::handle< BinMDataStd_IntegerArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerArrayDriver_Create()

def Handle_BinMDataStd_IntegerArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_IntegerArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerArrayDriver_DownCast(t)

def Handle_BinMDataStd_IntegerArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_IntegerArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_IntegerArrayDriver_IsNull(t)

def Handle_BinMDataStd_IntegerDriver_Create() -> "opencascade::handle< BinMDataStd_IntegerDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerDriver_Create()

def Handle_BinMDataStd_IntegerDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_IntegerDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerDriver_DownCast(t)

def Handle_BinMDataStd_IntegerDriver_IsNull(t: "opencascade::handle< BinMDataStd_IntegerDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_IntegerDriver_IsNull(t)

def Handle_BinMDataStd_IntegerListDriver_Create() -> "opencascade::handle< BinMDataStd_IntegerListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerListDriver_Create()

def Handle_BinMDataStd_IntegerListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_IntegerListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_IntegerListDriver_DownCast(t)

def Handle_BinMDataStd_IntegerListDriver_IsNull(t: "opencascade::handle< BinMDataStd_IntegerListDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_IntegerListDriver_IsNull(t)

def Handle_BinMDataStd_NamedDataDriver_Create() -> "opencascade::handle< BinMDataStd_NamedDataDriver >":
    return _BinMDataStd.Handle_BinMDataStd_NamedDataDriver_Create()

def Handle_BinMDataStd_NamedDataDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_NamedDataDriver >":
    return _BinMDataStd.Handle_BinMDataStd_NamedDataDriver_DownCast(t)

def Handle_BinMDataStd_NamedDataDriver_IsNull(t: "opencascade::handle< BinMDataStd_NamedDataDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_NamedDataDriver_IsNull(t)

def Handle_BinMDataStd_RealArrayDriver_Create() -> "opencascade::handle< BinMDataStd_RealArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealArrayDriver_Create()

def Handle_BinMDataStd_RealArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_RealArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealArrayDriver_DownCast(t)

def Handle_BinMDataStd_RealArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_RealArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_RealArrayDriver_IsNull(t)

def Handle_BinMDataStd_RealDriver_Create() -> "opencascade::handle< BinMDataStd_RealDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealDriver_Create()

def Handle_BinMDataStd_RealDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_RealDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealDriver_DownCast(t)

def Handle_BinMDataStd_RealDriver_IsNull(t: "opencascade::handle< BinMDataStd_RealDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_RealDriver_IsNull(t)

def Handle_BinMDataStd_RealListDriver_Create() -> "opencascade::handle< BinMDataStd_RealListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealListDriver_Create()

def Handle_BinMDataStd_RealListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_RealListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_RealListDriver_DownCast(t)

def Handle_BinMDataStd_RealListDriver_IsNull(t: "opencascade::handle< BinMDataStd_RealListDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_RealListDriver_IsNull(t)

def Handle_BinMDataStd_ReferenceArrayDriver_Create() -> "opencascade::handle< BinMDataStd_ReferenceArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceArrayDriver_Create()

def Handle_BinMDataStd_ReferenceArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ReferenceArrayDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceArrayDriver_DownCast(t)

def Handle_BinMDataStd_ReferenceArrayDriver_IsNull(t: "opencascade::handle< BinMDataStd_ReferenceArrayDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceArrayDriver_IsNull(t)

def Handle_BinMDataStd_ReferenceListDriver_Create() -> "opencascade::handle< BinMDataStd_ReferenceListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceListDriver_Create()

def Handle_BinMDataStd_ReferenceListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_ReferenceListDriver >":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceListDriver_DownCast(t)

def Handle_BinMDataStd_ReferenceListDriver_IsNull(t: "opencascade::handle< BinMDataStd_ReferenceListDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_ReferenceListDriver_IsNull(t)

def Handle_BinMDataStd_TreeNodeDriver_Create() -> "opencascade::handle< BinMDataStd_TreeNodeDriver >":
    return _BinMDataStd.Handle_BinMDataStd_TreeNodeDriver_Create()

def Handle_BinMDataStd_TreeNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_TreeNodeDriver >":
    return _BinMDataStd.Handle_BinMDataStd_TreeNodeDriver_DownCast(t)

def Handle_BinMDataStd_TreeNodeDriver_IsNull(t: "opencascade::handle< BinMDataStd_TreeNodeDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_TreeNodeDriver_IsNull(t)

def Handle_BinMDataStd_UAttributeDriver_Create() -> "opencascade::handle< BinMDataStd_UAttributeDriver >":
    return _BinMDataStd.Handle_BinMDataStd_UAttributeDriver_Create()

def Handle_BinMDataStd_UAttributeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_UAttributeDriver >":
    return _BinMDataStd.Handle_BinMDataStd_UAttributeDriver_DownCast(t)

def Handle_BinMDataStd_UAttributeDriver_IsNull(t: "opencascade::handle< BinMDataStd_UAttributeDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_UAttributeDriver_IsNull(t)

def Handle_BinMDataStd_VariableDriver_Create() -> "opencascade::handle< BinMDataStd_VariableDriver >":
    return _BinMDataStd.Handle_BinMDataStd_VariableDriver_Create()

def Handle_BinMDataStd_VariableDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinMDataStd_VariableDriver >":
    return _BinMDataStd.Handle_BinMDataStd_VariableDriver_DownCast(t)

def Handle_BinMDataStd_VariableDriver_IsNull(t: "opencascade::handle< BinMDataStd_VariableDriver > const &") -> "bool":
    return _BinMDataStd.Handle_BinMDataStd_VariableDriver_IsNull(t)
class binmdatastd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <thedrivertable>.

        Parameters
        ----------
        theDriverTable: BinMDF_ADriverTable
        aMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _BinMDataStd.binmdatastd_AddDrivers(*args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def SetAttributeID(self):
    	pass


    def __init__(self):
        _BinMDataStd.binmdatastd_swiginit(self, _BinMDataStd.new_binmdatastd())
    __swig_destroy__ = _BinMDataStd.delete_binmdatastd

# Register binmdatastd in _BinMDataStd:
_BinMDataStd.binmdatastd_swigregister(binmdatastd)

def binmdatastd_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <thedrivertable>.

    Parameters
    ----------
    theDriverTable: BinMDF_ADriverTable
    aMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _BinMDataStd.binmdatastd_AddDrivers(*args)

class BinMDataStd_AsciiStringDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_AsciiStringDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_AsciiStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_AsciiStringDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_AsciiStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_AsciiStringDriver

# Register BinMDataStd_AsciiStringDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_AsciiStringDriver_swigregister(BinMDataStd_AsciiStringDriver)

class BinMDataStd_BooleanArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_BooleanArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_BooleanArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_BooleanArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_BooleanArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_BooleanArrayDriver

# Register BinMDataStd_BooleanArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_BooleanArrayDriver_swigregister(BinMDataStd_BooleanArrayDriver)

class BinMDataStd_BooleanListDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_BooleanListDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_BooleanListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_BooleanListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_BooleanListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_BooleanListDriver

# Register BinMDataStd_BooleanListDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_BooleanListDriver_swigregister(BinMDataStd_BooleanListDriver)

class BinMDataStd_ByteArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ByteArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ByteArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ByteArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ByteArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ByteArrayDriver

# Register BinMDataStd_ByteArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ByteArrayDriver_swigregister(BinMDataStd_ByteArrayDriver)

class BinMDataStd_ExpressionDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ExpressionDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ExpressionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ExpressionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ExpressionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ExpressionDriver

# Register BinMDataStd_ExpressionDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ExpressionDriver_swigregister(BinMDataStd_ExpressionDriver)

class BinMDataStd_ExtStringArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ExtStringArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ExtStringArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ExtStringArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ExtStringArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ExtStringArrayDriver

# Register BinMDataStd_ExtStringArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ExtStringArrayDriver_swigregister(BinMDataStd_ExtStringArrayDriver)

class BinMDataStd_ExtStringListDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ExtStringListDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ExtStringListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ExtStringListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ExtStringListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ExtStringListDriver

# Register BinMDataStd_ExtStringListDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ExtStringListDriver_swigregister(BinMDataStd_ExtStringListDriver)

class BinMDataStd_GenericEmptyDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_GenericEmptyDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_GenericEmptyDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_GenericEmptyDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_GenericEmptyDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_GenericEmptyDriver

# Register BinMDataStd_GenericEmptyDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_GenericEmptyDriver_swigregister(BinMDataStd_GenericEmptyDriver)

class BinMDataStd_GenericExtStringDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_GenericExtStringDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_GenericExtStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_GenericExtStringDriver_Paste(self, *args)

    def SourceType(self, *args) -> "opencascade::handle< Standard_Type > &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Standard_Type>

        """
        return _BinMDataStd.BinMDataStd_GenericExtStringDriver_SourceType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_GenericExtStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_GenericExtStringDriver

# Register BinMDataStd_GenericExtStringDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_GenericExtStringDriver_swigregister(BinMDataStd_GenericExtStringDriver)

class BinMDataStd_IntPackedMapDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_IntPackedMapDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_IntPackedMapDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_IntPackedMapDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_IntPackedMapDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_IntPackedMapDriver

# Register BinMDataStd_IntPackedMapDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_IntPackedMapDriver_swigregister(BinMDataStd_IntPackedMapDriver)

class BinMDataStd_IntegerArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_IntegerArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_IntegerArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_IntegerArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_IntegerArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_IntegerArrayDriver

# Register BinMDataStd_IntegerArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_IntegerArrayDriver_swigregister(BinMDataStd_IntegerArrayDriver)

class BinMDataStd_IntegerDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_IntegerDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_IntegerDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_IntegerDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_IntegerDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_IntegerDriver

# Register BinMDataStd_IntegerDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_IntegerDriver_swigregister(BinMDataStd_IntegerDriver)

class BinMDataStd_IntegerListDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_IntegerListDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_IntegerListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_IntegerListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_IntegerListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_IntegerListDriver

# Register BinMDataStd_IntegerListDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_IntegerListDriver_swigregister(BinMDataStd_IntegerListDriver)

class BinMDataStd_NamedDataDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_NamedDataDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_NamedDataDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_NamedDataDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_NamedDataDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_NamedDataDriver

# Register BinMDataStd_NamedDataDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_NamedDataDriver_swigregister(BinMDataStd_NamedDataDriver)

class BinMDataStd_RealArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_RealArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_RealArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_RealArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_RealArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_RealArrayDriver

# Register BinMDataStd_RealArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_RealArrayDriver_swigregister(BinMDataStd_RealArrayDriver)

class BinMDataStd_RealDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_RealDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_RealDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_RealDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_RealDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_RealDriver

# Register BinMDataStd_RealDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_RealDriver_swigregister(BinMDataStd_RealDriver)

class BinMDataStd_RealListDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_RealListDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_RealListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_RealListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_RealListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_RealListDriver

# Register BinMDataStd_RealListDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_RealListDriver_swigregister(BinMDataStd_RealListDriver)

class BinMDataStd_ReferenceArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ReferenceArrayDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ReferenceArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ReferenceArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ReferenceArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ReferenceArrayDriver

# Register BinMDataStd_ReferenceArrayDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ReferenceArrayDriver_swigregister(BinMDataStd_ReferenceArrayDriver)

class BinMDataStd_ReferenceListDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_ReferenceListDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_ReferenceListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_ReferenceListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_ReferenceListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_ReferenceListDriver

# Register BinMDataStd_ReferenceListDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_ReferenceListDriver_swigregister(BinMDataStd_ReferenceListDriver)

class BinMDataStd_TreeNodeDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_TreeNodeDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_TreeNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_TreeNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_TreeNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_TreeNodeDriver

# Register BinMDataStd_TreeNodeDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_TreeNodeDriver_swigregister(BinMDataStd_TreeNodeDriver)

class BinMDataStd_UAttributeDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_UAttributeDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_UAttributeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_UAttributeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_UAttributeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_UAttributeDriver

# Register BinMDataStd_UAttributeDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_UAttributeDriver_swigregister(BinMDataStd_UAttributeDriver)

class BinMDataStd_VariableDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinMDataStd.BinMDataStd_VariableDriver_swiginit(self, _BinMDataStd.new_BinMDataStd_VariableDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinMDataStd.BinMDataStd_VariableDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinMDataStd_VariableDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinMDataStd.delete_BinMDataStd_VariableDriver

# Register BinMDataStd_VariableDriver in _BinMDataStd:
_BinMDataStd.BinMDataStd_VariableDriver_swigregister(BinMDataStd_VariableDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.Bnd import *


class brepbndlib:
	@staticmethod
	def Add(S: TopoDS_Shape, B: Bnd_Box, useTriangulation: Optional[bool] = True) -> None: ...
	@staticmethod
	def AddClose(S: TopoDS_Shape, B: Bnd_Box) -> None: ...
	@staticmethod
	def AddOBB(theS: TopoDS_Shape, theOBB: Bnd_OBB, theIsTriangulationUsed: Optional[bool] = True, theIsOptimal: Optional[bool] = False, theIsShapeToleranceUsed: Optional[bool] = True) -> None: ...
	@staticmethod
	def AddOptimal(S: TopoDS_Shape, B: Bnd_Box, useTriangulation: Optional[bool] = True, useShapeTolerance: Optional[bool] = False) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

brepbndlib_Add = brepbndlib.Add
brepbndlib_AddClose = brepbndlib.AddClose
brepbndlib_AddOBB = brepbndlib.AddOBB
brepbndlib_AddOptimal = brepbndlib.AddOptimal



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Interface import *
from OCC.Core.TColStd import *
from OCC.Core.TopTools import *
from OCC.Core.Message import *
from OCC.Core.Transfer import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *


class TransferBRep_SequenceOfTransferResultInfo:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class transferbrep:
	@staticmethod
	def CheckObject(chl: Interface_CheckIterator, obj: Standard_Transient) -> Interface_CheckIterator: ...
	@staticmethod
	def Checked(chl: Interface_CheckIterator, alsoshapes: Optional[bool] = False) -> TColStd_HSequenceOfTransient: ...
	@staticmethod
	def CheckedShapes(chl: Interface_CheckIterator) -> TopTools_HSequenceOfShape: ...
	@staticmethod
	def PrintResultInfo(Printer: Message_Printer, Header: Message_Msg, ResultInfo: TransferBRep_TransferResultInfo, printEmpty: Optional[bool] = True) -> None: ...
	@staticmethod
	def ResultCheckList(chl: Interface_CheckIterator, FP: Transfer_FinderProcess, model: Interface_InterfaceModel) -> Interface_CheckIterator: ...
	@staticmethod
	def ResultFromShape(FP: Transfer_FinderProcess, shape: TopoDS_Shape) -> Transfer_Binder: ...
	@staticmethod
	def SetShapeResult(TP: Transfer_TransientProcess, ent: Standard_Transient, result: TopoDS_Shape) -> None: ...
	@staticmethod
	def SetTransientFromShape(FP: Transfer_FinderProcess, shape: TopoDS_Shape, result: Standard_Transient) -> None: ...
	@staticmethod
	def ShapeMapper(FP: Transfer_FinderProcess, shape: TopoDS_Shape) -> TransferBRep_ShapeMapper: ...
	@overload
	@staticmethod
	def ShapeResult(binder: Transfer_Binder) -> TopoDS_Shape: ...
	@overload
	@staticmethod
	def ShapeResult(TP: Transfer_TransientProcess, ent: Standard_Transient) -> TopoDS_Shape: ...
	@staticmethod
	def ShapeState(FP: Transfer_FinderProcess, shape: TopoDS_Shape) -> TopAbs_Orientation: ...
	@overload
	@staticmethod
	def Shapes(TP: Transfer_TransientProcess, rootsonly: Optional[bool] = True) -> TopTools_HSequenceOfShape: ...
	@overload
	@staticmethod
	def Shapes(TP: Transfer_TransientProcess, list: TColStd_HSequenceOfTransient) -> TopTools_HSequenceOfShape: ...
	@overload
	@staticmethod
	def TransferResultInfo(TP: Transfer_TransientProcess, EntityTypes: TColStd_HSequenceOfTransient, InfoSeq: TransferBRep_HSequenceOfTransferResultInfo) -> None: ...
	@overload
	@staticmethod
	def TransferResultInfo(FP: Transfer_FinderProcess, ShapeTypes: TColStd_HSequenceOfInteger, InfoSeq: TransferBRep_HSequenceOfTransferResultInfo) -> None: ...
	@staticmethod
	def TransientFromShape(FP: Transfer_FinderProcess, shape: TopoDS_Shape) -> Standard_Transient: ...

class TransferBRep_BinderOfShape(Transfer_Binder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, res: TopoDS_Shape) -> None: ...
	def CResult(self) -> TopoDS_Shape: ...
	def Result(self) -> TopoDS_Shape: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def SetResult(self, res: TopoDS_Shape) -> None: ...

class TransferBRep_OrientedShapeMapper(Transfer_Finder):
	def __init__(self, akey: TopoDS_Shape) -> None: ...
	def Equates(self, other: Transfer_Finder) -> bool: ...
	def Value(self) -> TopoDS_Shape: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

class TransferBRep_Reader:
	def __init__(self) -> None: ...
	def Actor(self) -> Transfer_ActorOfTransientProcess: ...
	def BeginTransfer(self) -> bool: ...
	def CheckListModel(self) -> Interface_CheckIterator: ...
	def CheckListResult(self) -> Interface_CheckIterator: ...
	def CheckStatusModel(self, withprint: bool) -> bool: ...
	def CheckStatusResult(self, withprints: bool) -> bool: ...
	def Clear(self) -> None: ...
	def EndTransfer(self) -> None: ...
	def FileNotFound(self) -> bool: ...
	def FileStatus(self) -> int: ...
	def IsDone(self) -> bool: ...
	def GetModeNewTransfer(self) -> bool: ...
	def SetModeNewTransfer(self, value: bool) -> None: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def NbShapes(self) -> int: ...
	def NbTransients(self) -> int: ...
	def OneShape(self) -> TopoDS_Shape: ...
	def PrepareTransfer(self) -> None: ...
	def Protocol(self) -> Interface_Protocol: ...
	def SetActor(self, actor: Transfer_ActorOfTransientProcess) -> None: ...
	def SetFileStatus(self, status: int) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def SetProtocol(self, protocol: Interface_Protocol) -> None: ...
	def Shape(self, num: Optional[int] = 1) -> TopoDS_Shape: ...
	def ShapeResult(self, ent: Standard_Transient) -> TopoDS_Shape: ...
	def Shapes(self) -> TopTools_HSequenceOfShape: ...
	def SyntaxError(self) -> bool: ...
	def Transfer(self, num: int, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def TransferList(self, list: TColStd_HSequenceOfTransient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def TransferRoots(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def Transient(self, num: Optional[int] = 1) -> Standard_Transient: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...
	def Transients(self) -> TColStd_HSequenceOfTransient: ...

class TransferBRep_ShapeInfo:
	@staticmethod
	def Type(ent: TopoDS_Shape) -> Standard_Type: ...
	@staticmethod
	def TypeName(ent: TopoDS_Shape) -> str: ...

class TransferBRep_ShapeListBinder(Transfer_Binder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, list: TopTools_HSequenceOfShape) -> None: ...
	def AddResult(self, res: TopoDS_Shape) -> None: ...
	def CompSolid(self, num: int) -> TopoDS_CompSolid: ...
	def Compound(self, num: int) -> TopoDS_Compound: ...
	def Edge(self, num: int) -> TopoDS_Edge: ...
	def Face(self, num: int) -> TopoDS_Face: ...
	def IsMultiple(self) -> bool: ...
	def NbShapes(self) -> int: ...
	def Result(self) -> TopTools_HSequenceOfShape: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def SetResult(self, num: int, res: TopoDS_Shape) -> None: ...
	def Shape(self, num: int) -> TopoDS_Shape: ...
	def ShapeType(self, num: int) -> TopAbs_ShapeEnum: ...
	def Shell(self, num: int) -> TopoDS_Shell: ...
	def Solid(self, num: int) -> TopoDS_Solid: ...
	def Vertex(self, num: int) -> TopoDS_Vertex: ...
	def Wire(self, num: int) -> TopoDS_Wire: ...

class TransferBRep_ShapeMapper(Transfer_Finder):
	def __init__(self, akey: TopoDS_Shape) -> None: ...
	def Equates(self, other: Transfer_Finder) -> bool: ...
	def Value(self) -> TopoDS_Shape: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

class TransferBRep_TransferResultInfo(Standard_Transient):
	def __init__(self) -> None: ...
	def Clear(self) -> None: ...
	def GetNoResult(self) -> int: ...
	def SetNoResult(self, value: int) -> None: ...
	def GetNoResultFail(self) -> int: ...
	def SetNoResultFail(self, value: int) -> None: ...
	def GetNoResultWarning(self) -> int: ...
	def SetNoResultWarning(self, value: int) -> None: ...
	def GetNoResultWarningFail(self) -> int: ...
	def SetNoResultWarningFail(self, value: int) -> None: ...
	def GetResult(self) -> int: ...
	def SetResult(self, value: int) -> None: ...
	def GetResultFail(self) -> int: ...
	def SetResultFail(self, value: int) -> None: ...
	def GetResultWarning(self) -> int: ...
	def SetResultWarning(self, value: int) -> None: ...
	def GetResultWarningFail(self) -> int: ...
	def SetResultWarningFail(self, value: int) -> None: ...

class TransferBRep_ShapeBinder(TransferBRep_BinderOfShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, res: TopoDS_Shape) -> None: ...
	def CompSolid(self) -> TopoDS_CompSolid: ...
	def Compound(self) -> TopoDS_Compound: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Face(self) -> TopoDS_Face: ...
	def ShapeType(self) -> TopAbs_ShapeEnum: ...
	def Shell(self) -> TopoDS_Shell: ...
	def Solid(self) -> TopoDS_Solid: ...
	def Vertex(self) -> TopoDS_Vertex: ...
	def Wire(self) -> TopoDS_Wire: ...

# harray1 classes
# harray2 classes
# hsequence classes

class TransferBRep_HSequenceOfTransferResultInfo(TransferBRep_SequenceOfTransferResultInfo, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TransferBRep_SequenceOfTransferResultInfo) -> None: ...
    def Sequence(self) -> TransferBRep_SequenceOfTransferResultInfo: ...
    def Append(self, theSequence: TransferBRep_SequenceOfTransferResultInfo) -> None: ...


transferbrep_CheckObject = transferbrep.CheckObject
transferbrep_Checked = transferbrep.Checked
transferbrep_CheckedShapes = transferbrep.CheckedShapes
transferbrep_PrintResultInfo = transferbrep.PrintResultInfo
transferbrep_ResultCheckList = transferbrep.ResultCheckList
transferbrep_ResultFromShape = transferbrep.ResultFromShape
transferbrep_SetShapeResult = transferbrep.SetShapeResult
transferbrep_SetTransientFromShape = transferbrep.SetTransientFromShape
transferbrep_ShapeMapper = transferbrep.ShapeMapper
transferbrep_ShapeResult = transferbrep.ShapeResult
transferbrep_ShapeResult = transferbrep.ShapeResult
transferbrep_ShapeState = transferbrep.ShapeState
transferbrep_Shapes = transferbrep.Shapes
transferbrep_Shapes = transferbrep.Shapes
transferbrep_TransferResultInfo = transferbrep.TransferResultInfo
transferbrep_TransferResultInfo = transferbrep.TransferResultInfo
transferbrep_TransientFromShape = transferbrep.TransientFromShape
TransferBRep_ShapeInfo_Type = TransferBRep_ShapeInfo.Type
TransferBRep_ShapeInfo_TypeName = TransferBRep_ShapeInfo.TypeName
